/*
 * 8 avril 2007
 * 
 * SCALP - Système de Cartographie Automatique Libre pour la Pédagogie
 * Version beta 0.94
 *
 * Copyright 1997-2007 Université de Toulouse Le Mirail / Département de Géographie / Laurent Jégou
 * Portions : 	Copyright (c) 2004 Sun Microsystems (file filter, AbstractLayout)
 * 				Copyright 1999, 2000, 2001, 2002 by Bruno Lowagie (iText pdf exports)
 * 				Copyright (C) 2001 Andrew Khan (jxl import/export format Excelé)
 * http://www.univ-tlse2.fr/geoprdc
 * jegou@univ-tlse2.fr
 * 
 * Ce programme est un logiciel libre régi par la licence CeCILL (cf. lien ci-dessous), cette licence confére
 * aux utilisateurs la liberté de modification et de redistribution du logiciel, dans le cadre d'un modéle de
 * diffusion open-source.
 * L'exercice de ces libertés est assorti de certains devoirs é la charge des utilisateurs afin de préserver
 * ce statut au cours des redistributions ultérieures.
 * Léaccessibilité au code source et les droits de copie, de modification et de redistribution qui en découlent
 * ont pour contrepartie de néoffrir aux utilisateurs quéune garantie limitée et de ne faire peser sur léauteur
 * le titulaire des droits patrimoniaux et les concédants successifs quéune responsabilité restreinte.
 * 
 * Le texte intégral de la licence se trouve dans la disribution, ou é l'adresse suivante :
 * http://www.cecill.info
 */

package guiInterface;

import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Cursor;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Point;
import java.awt.Rectangle;
import java.awt.RenderingHints;
import java.awt.Stroke;
import java.awt.event.MouseEvent;
import java.awt.geom.Rectangle2D;
import java.awt.print.PageFormat;
import java.awt.print.Printable;
import java.util.Iterator;

import javax.swing.JComponent;
import javax.swing.JOptionPane;
import javax.swing.event.MouseInputListener;

import carto.FondCarte;
import carto.MetaPolygone;

/**
 * @author Laurent, portage Java du code VB.Net de Duncan Mackenzie
 * 
 */

public class DesignSurface extends JComponent implements MouseInputListener, Printable {
    
    private Color aColor = Color.black;

    private Font aFonte = Font.decode("Arial-12"); //$NON-NLS-1$

    private String aTexte;
    
    private double aEchelle;

    public FenetreMiseEnPage base;

    private boolean dragging = false;

    private Point dragOffset = new Point(0, 0);

    private int inputHeight = 0;

    private int inputWidth = 0;

    private GraphicObjectsCollection m_drawingObjects = new GraphicObjectsCollection();

    private boolean m_ExpPDF = false;

    private Color m_GridColor = Color.cyan;

    private int m_GridLineWidth = 1;

    private double m_GridSize = 39.37;

    private int m_HorizRes = 1000;

    private Color m_MarginColor = Color.green;

    private int m_MarginLineWidth = 1;

    private Color m_NonPrintingAreaColor = Color.gray;

    private GraphicObject m_selectedObject;

    private boolean m_ShowGrid = true;

    private String m_Souris = ""; //$NON-NLS-1$

    private Rectangle m_SurfaceBounds = new Rectangle(0, 0, 850, 1100);

    private Rectangle m_SurfaceMargins = new Rectangle(10, 10, 840, 1090);

    private int m_VertRes = 1000;

    private double m_Zoom = 0.5;

    private float MinimumGridSize = 20;
    
    private double originalRotation = 0;
    
    private boolean rotating = false;
    
    private boolean selectionDragging = false;
    
    private Rectangle selectionRect = new Rectangle();
    
    private Point shapePosition = new Point(0,0);
    
    private double startingRotation = 0;
    
    private Rectangle traceRect = new Rectangle();
        
    public DesignSurface(FenetreMiseEnPage base) {
        super();
        this.base = base;

        addMouseListener(this);
        addMouseMotionListener(this);
        this.repaint();
    }

    public double angleToPoint(Point origine, Point destination) {
        double angle = 0;
        destination.x = destination.x - origine.x;
        destination.y = destination.y - origine.y;
        angle = Math.atan2(destination.y, destination.x) / (Math.PI / 180);
        return angle;
    }

    protected double ConvertToHPixels(double valeur) {
        return valeur * this.m_HorizRes;
    }

    protected Rectangle ConvertToPixels(Rectangle rect) {
        Rectangle Bounds;
        Bounds = new Rectangle((int) ConvertToHPixels(rect.x / 72), (int) ConvertToVPixels(rect.y / 72), (int) ConvertToHPixels(rect.width / 72), (int) ConvertToVPixels(rect.height / 72));
        return Bounds;
    }

    protected double ConvertToVPixels(double valeur) {
        return valeur * this.m_VertRes;
    }

    private void deleteAllObjects() {
        this.getDrawingObjects().clear();
        this.repaint();
    }

    public void deleteSelectedObject() {
        GraphicObject oD = new GraphicObject();
        oD = this.m_selectedObject;
        if (oD != null) {
            if (this.getDrawingObjects().contains(oD)) {
                this.getDrawingObjects().remove(oD);
                this.m_selectedObject = null;
                oD = null;
                this.repaint();
            }
        }
    }

    protected Rectangle deZoomRect(Rectangle rect) {
        Rectangle newRect;
        newRect = new Rectangle((int) (rect.x / this.m_Zoom), (int) (rect.y / this.m_Zoom), (int) (rect.width / this.m_Zoom), (int) (rect.height / this.m_Zoom));
        return newRect;
    }

    protected void drawGrid(Graphics g) {
        Graphics2D g2 = (Graphics2D) g;
        Stroke originePen = g2.getStroke();
        Rectangle Bounds;
        int HGridSize = (int) (ConvertToHPixels(getGridSize() / 100) * this.m_Zoom);
        int VGridSize = (int) (ConvertToVPixels(getGridSize() / 100) * this.m_Zoom);
        Bounds = ConvertToPixels(getSurfaceBounds());
        Bounds = zoomRectangle(Bounds);
        Rectangle ClipBounds = Bounds; //new Rectangle(g.getClipBounds());

        //g2.setColor(m_NonPrintingAreaColor);
        //g2.fillRect(ClipBounds.x, ClipBounds.y, ClipBounds.width, ClipBounds.height);
        g2.setColor(Color.white);
        g2.fillRect(Bounds.x, Bounds.y, Bounds.width, Bounds.height);
        g2.setPaint(this.m_GridColor);
        g2.setStroke(new BasicStroke(this.m_GridLineWidth));
        int i = 0;
        for (i = VGridSize; i < Bounds.height; i += VGridSize) {
            g.drawLine(0, i, Bounds.width, i);
        }
        for (i = HGridSize; i < Bounds.width; i += HGridSize) {
            g.drawLine(i, 0, i, Bounds.height);
        }
        g2.setStroke(originePen);
    }

    protected void drawMargins(Graphics g) {
        Graphics2D g2 = (Graphics2D) g;
        Stroke originePen = g2.getStroke();
        Rectangle margins = ConvertToPixels(this.m_SurfaceMargins);
        BasicStroke marginPen = new BasicStroke(this.m_MarginLineWidth, BasicStroke.CAP_BUTT, BasicStroke.JOIN_MITER, 10, new float[] {6, 2}, 0);
        g2.setStroke(marginPen);
        g2.setPaint(this.m_MarginColor);        
        g2.drawRect(margins.x, margins.y, margins.width, margins.height);
        g2.setStroke(originePen);
    }

    private void drawSelectionRectangle(Graphics g, Rectangle selectionRect) {
        Graphics2D g2 = (Graphics2D) g;
        Color selection = new Color(75, 120, 120, 120);
        g2.setPaint(selection);
        g2.fillRect(selectionRect.x, selectionRect.y, selectionRect.width, selectionRect.height);
    }

    private void drawTraceEllipse(Graphics g, Rectangle traceRect) {
        Graphics2D g2 = (Graphics2D) g;
        Color trace = new Color(20, 0, 0, 255);
        g2.setPaint(trace);
        g2.fillOval(traceRect.x, traceRect.y, traceRect.width, traceRect.height);
    }

    private void drawTraceLigne(Graphics g, Rectangle traceRect) {
        Graphics2D g2 = (Graphics2D) g;
        Color trace = new Color(20, 0, 0, 255);
        g2.setPaint(trace);
        g2.drawLine(traceRect.x, traceRect.y, traceRect.x + traceRect.width, traceRect.y + traceRect.height);
    }

    private void drawTraceRectangle(Graphics g, Rectangle traceRect) {
        Graphics2D g2 = (Graphics2D) g;
        Color trace = new Color(60, 120, 120, 120);
        g2.setPaint(trace);
        g2.fillRect(traceRect.x, traceRect.y, traceRect.width, traceRect.height);
    }

    /**
     * @return Returns the aColor.
     */
    public Color getAColor() {
        return aColor;
    }

    /**
     * @return Returns the aFonte.
     */
    public Font getAFonte() {
        return aFonte;
    }

    /**
     * @return Returns the aTexte.
     */
    public String getATexte() {
        return aTexte;
    }

    public GraphicObjectsCollection getDrawingObjects() {
        return m_drawingObjects;
    }

    public double getEcartGrille() {
        return m_GridSize;
    }

    public boolean getExpPDF() {
        return m_ExpPDF;
    }

    public int getGridLineWidth() {
        return m_GridLineWidth;
    }

    public double getGridSize() {
        return m_GridSize;
    }

    public Color getMarginColor() {
        return m_MarginColor;
    }

    public int getMarginLineWidth() {
        return m_MarginLineWidth;
    }

    public Color getNonPrintingAreaColor() {
        return m_NonPrintingAreaColor;
    }

    public GraphicObject getSelectedObject() {
        return m_selectedObject;
    }

    public boolean getShowGrid() {
        return m_ShowGrid;
    }

    public String getSouris() {
        return m_Souris;
    }

    public Rectangle getSurfaceBounds() {
        return m_SurfaceBounds;
    }

    public Rectangle getSurfaceMargins() {
        return m_SurfaceMargins;
    }

    public double getZoom() {
        return m_Zoom;
    }

    public Point gocTogsc(Point goPt) {
        Point newPt = new Point();
        newPt.x = (int) (goPt.x * this.getZoom());
        newPt.x = (int) (goPt.y * this.getZoom());
        return newPt;
    }
    
    public Point gocTogscXY(int x, int y) {
        Point newPt = new Point();
        newPt.x = (int) (x * this.getZoom());
        newPt.y = (int) (y * this.getZoom());
        return newPt;
    }

    public Point gscTogoc(Point gsPt) {
        Point newPt = new Point();
        newPt.x = (int) (gsPt.x / this.getZoom());
        newPt.y = (int) (gsPt.y / this.getZoom());
        return newPt;
    }

    public int gscTogocValeur(int valeur) {
        int hauteur = (int) (valeur / this.getZoom());
        return hauteur;
    }

    public Point gscTogocXY(int x, int y) {
        Point newPt = new Point();
        newPt.x = (int) (x / this.getZoom());
        newPt.y = (int) (y / this.getZoom());
        return newPt;
    }

    public void mouseClicked(MouseEvent me) {
    	GraphicObject go;
    	Point mousePt = new Point(gscTogocXY(me.getX(), me.getY()));
    	if (me.getClickCount() >= 2) {
    		go = m_drawingObjects.findObjectAtPoint(mousePt);
    	} else go = null;
    	if (go != null) {
    		if (go.getClass() == goTexte.class) {
    			goTexte gotx = (goTexte)go;
    			String ntxt = this.base.modifTexte(gotx);
    			if (ntxt == "") return;
    			gotx.setTexte(ntxt);
    			gotx.setCouleur(this.aColor);
    			gotx.setFont(this.aFonte);
    			this.base.repaint();
    		}
    	}
    }

    public void mouseDragged(MouseEvent me) {
        Point dragPoint = new Point(gscTogocXY(me.getX(), me.getY()));
        //Point dragPoint = new Point(me.getX(), me.getY());

        if (m_selectedObject != null) {
            if (dragging) {
                dragPoint.x += dragOffset.x;
                dragPoint.y += dragOffset.y;
                m_selectedObject.setPosition(dragPoint);
                this.repaint();
            }
            if (rotating) {
                double currentRotation = angleToPoint(m_selectedObject.getPosition(), dragPoint);
                currentRotation = (int) ((currentRotation - startingRotation + originalRotation) % 360);
                m_selectedObject.setRotation(currentRotation);
                this.repaint();
            }
        } else {
            if (selectionDragging) {
                if (m_Souris != "") //$NON-NLS-1$
                	selectionRect.width = dragPoint.x - selectionRect.x;
                	selectionRect.height = dragPoint.y - selectionRect.y;
                	this.repaint();
            } else {
                if (m_Souris != "") { //$NON-NLS-1$
                    traceRect.width = me.getX() - traceRect.x;
                    traceRect.height = me.getY() - traceRect.y;
                    this.repaint();
                }
            }
        }
    }

    public void mouseEntered(MouseEvent me) {

    }

    public void mouseExited(MouseEvent me) {

    }

    public void mouseMoved(MouseEvent me) {
        //Voir mouseDragged();
    }

    public void mousePressed(MouseEvent me) {
        Point mousePt = new Point(gscTogocXY(me.getX(), me.getY()));      
        
        if (m_Souris.equals("CarteDebut")) { //$NON-NLS-1$
            shapePosition = mousePt;
            m_Souris = "CarteFin"; //$NON-NLS-1$
        }
        
        if (m_Souris.equals("LegendeDebut")) { //$NON-NLS-1$
        	shapePosition = mousePt;
        	m_Souris = "LegendeFin"; //$NON-NLS-1$
        }
        
        if (m_Souris.equals("TexteDebut")) { //$NON-NLS-1$
            shapePosition = mousePt;
            GraphicObject goSouris = new goTexte(shapePosition, aTexte, aFonte, aColor);
            this.getDrawingObjects().add(goSouris);
            setSouris(""); //$NON-NLS-1$
            this.setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
            this.repaint();
        }

        if (m_Souris.equals("RectangleDebut")) { //$NON-NLS-1$
            shapePosition = mousePt;
            m_Souris = "RectangleFin"; //$NON-NLS-1$
        }
        
        if (m_Souris.equals("Etiquette")) { //$NON-NLS-1$
        	String eTexte = "";
            shapePosition = mousePt;
            goCarte laCarte = (goCarte) m_drawingObjects.findObjectAtPoint(mousePt);
            if (laCarte == null) return;
            Point pt = new Point(0, 0);
            pt.x = mousePt.x - laCarte.getX();
            pt.y = mousePt.y - laCarte.getY();
            MetaPolygone mp = (MetaPolygone)(laCarte.getFondCarte().findPolygoneAt(pt));
            if (mp != null) {
            	 eTexte = mp.getNom();
            }
            GraphicObject goSouris = new goTexte(shapePosition, eTexte, aFonte, aColor);
            this.getDrawingObjects().add(goSouris);
            setSouris(""); //$NON-NLS-1$
            this.setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
            this.repaint();
        }
        
        if (m_Souris.equals("Echelle")) {
        	int i = 0;
        	int lapx = 0;
        	double coefUnit = 1;
            shapePosition = mousePt;
            goCarte laCarte = null;
            for (i = m_drawingObjects.size(); i > 0 ; i--) {
            	if (m_drawingObjects.get(i - 1).getClass() == goCarte.class)
            		laCarte = (goCarte) m_drawingObjects.get(i - 1);
            }            
            if (laCarte == null) {
            	JOptionPane.showMessageDialog(base, Messages.getString("DesignSurface.0")); //$NON-NLS-1$
            	return;
            }
            if (laCarte.getFondCarte().getUniteCoord() == "inconnu" || laCarte.getFondCarte().getUniteCoord() == null) {
            	JOptionPane.showMessageDialog(base, Messages.getString("DesignSurface.1")); //$NON-NLS-1$
            	m_Souris.equals("");
            	return;
            }
            if (laCarte.getFondCarte().getUniteCoord().equals("m"))
            	coefUnit = 1000;
            lapx = (int)((aEchelle * coefUnit) * (laCarte.getWidth() / laCarte.getFondCarte().getLargeur()));
            GraphicObject goSouris = new goEchelle(shapePosition, new Dimension(lapx, 20), (int)aEchelle);
            this.m_drawingObjects.add(goSouris);
            setSouris(""); //$NON-NLS-1$
            this.setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
            this.repaint();
        }
        
        if (m_Souris.equals("Nord")) { //$NON-NLS-1$
            shapePosition = mousePt;
            GraphicObject goSouris = new goNord(shapePosition);
            this.getDrawingObjects().add(goSouris);
            setSouris(""); //$NON-NLS-1$
            this.setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
            this.repaint();
        }
        
        if (m_Souris != "") { //$NON-NLS-1$
            traceRect.x = me.getX();
            traceRect.y = me.getY();
            traceRect.width = 0;
            traceRect.height = 0;
            return;
        }
        
        if (this.getDrawingObjects().size() != 0) {
            GraphicObject selection = this.getDrawingObjects().findObjectAtPoint(mousePt);
            if (selection != null) {
                this.setSelectedObject(selection);
                this.repaint();
            } else {
                this.setSelectedObject(null);
            }
        }
        this.repaint();

        if (m_selectedObject != null) {
            if (this.getSouris().equals("Rotation")) { //$NON-NLS-1$
                rotating = true;
                startingRotation = angleToPoint(m_selectedObject.getPosition(), mousePt);
                originalRotation = m_selectedObject.getRotation();
            } else {
                dragging = true;
                dragOffset.x = m_selectedObject.getX() - mousePt.x;
                dragOffset.y = m_selectedObject.getY() - mousePt.y;
            }
        } else {
            if (me.getButton() == MouseEvent.BUTTON1) {
                selectionDragging = true;
                selectionRect.x = mousePt.x; //me.getX();
                selectionRect.y  = mousePt.y; //me.getY();
                selectionRect.width = 0;
                selectionRect.height = 0;
            }
        }
    }

    public void mouseReleased(MouseEvent me) {
        Point mousePt = new Point(gscTogocXY(me.getX(), me.getY()));
        
        dragging = false;
        rotating = false;
        
        if (m_Souris.equals("CarteFin")) { //$NON-NLS-1$
            inputWidth = Math.abs(mousePt.x - shapePosition.x);
            inputHeight = Math.abs(mousePt.y - shapePosition.y);
            FondCarte mepFond = base.getBase().fenetre.panneauCarte.getFondCarte();
            Dimension taille = new Dimension(inputWidth, inputHeight);
            //shapePosition.y = shapePosition.y + inputHeight;
            GraphicObject goSouris = new goCarte(shapePosition, taille, mepFond);
            this.getDrawingObjects().add(goSouris);
            setSouris(""); //$NON-NLS-1$
            this.setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
            this.repaint();
        }
        
        if (m_Souris.equals("LegendeFin")) { //$NON-NLS-1$
            inputWidth = Math.abs(mousePt.x - shapePosition.x);
            inputHeight = Math.abs(mousePt.y - shapePosition.y);
            PanneauLegende PanLegende = base.getBase().fenLegende.panneauLegende;
            Dimension taille = new Dimension(inputWidth, inputHeight);
            GraphicObject goSouris = new goLegende(shapePosition, taille, PanLegende);
            this.getDrawingObjects().add(goSouris);
            setSouris(""); //$NON-NLS-1$
            this.setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
            this.repaint();
        }
        
        if (m_Souris.equals("RectangleFin")) { //$NON-NLS-1$
            inputWidth = Math.abs(mousePt.x - shapePosition.x);
            inputHeight = Math.abs(mousePt.y - shapePosition.y);
            Dimension taille = new Dimension(inputWidth, inputHeight);
            GraphicObject goSouris = new goRectangle(shapePosition, taille);
            this.getDrawingObjects().add(goSouris);
            setSouris(""); //$NON-NLS-1$
            this.setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
            this.repaint();
        }
        
        if (selectionDragging) {
            Rectangle2D zS = selectionRect;
            GraphicObject GO;
            Iterator goIterator = this.getDrawingObjects().iterator();
            while (goIterator.hasNext()) {
                GO = (GraphicObject) goIterator.next();
                if (GO.hitTest(zS)) {
                    this.setSelectedObject(GO);
                    break;
                }
            }
            selectionDragging = false;
            this.repaint();
        }
        traceRect.x = 0;
        traceRect.y = 0;
        traceRect.width = 0;
        traceRect.height = 0;
    }

    public void paintComponent(Graphics g) {
        super.paintComponent(g);
        Graphics2D g2 = (Graphics2D) g;
        RenderingHints hints = new RenderingHints(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
        g2.setRenderingHints(hints);
        this.m_HorizRes = 72;
        this.m_VertRes = 72;
        
        if (this.m_ExpPDF == false) drawGrid(g);
        /*
         * Iterator objets = getDrawingObjects().iterator(); while
         * (objets.hasNext()) { GraphicObject ob = (GraphicObject)objets.next();
         * ob.HorizontalResolution = 72; ob.VerticalResolution = 72;
         * ob.drawObjects(g, this.getZoom()); ob.drawSelectedObject(g,
         * m_selectedObject, this.getZoom()); }
         */
        getDrawingObjects().setHorizRes(72);
        getDrawingObjects().setVertRes(72);
        getDrawingObjects().drawObjects(g, this.getZoom());
        if (this.m_ExpPDF == false) {
            getDrawingObjects().drawSelectedObject(g, m_selectedObject, this.getZoom());
        	drawMargins(g);
        }
        
        if (selectionDragging) {
            drawSelectionRectangle(g, selectionRect);
        }
        
        switch (typeSouris(m_Souris)) {
        case 0:
            drawTraceRectangle(g, traceRect);
            break;
        case 1:
            drawTraceEllipse(g, traceRect);
            break;
        case 2:
            drawTraceLigne(g, traceRect);
            break;
        case 3:
            drawTraceRectangle(g, traceRect);
            break;
        case 4:
            drawTraceRectangle(g, traceRect);
            break;
        case 5:
            drawTraceRectangle(g, traceRect);
            break;
        case 6:
            drawTraceRectangle(g, traceRect);
            break;
        case 7:
            drawTraceEllipse(g, traceRect);
        }
    }

    public int print(Graphics g, PageFormat pf, int pageIndex) {
        if (pageIndex != 0) return NO_SUCH_PAGE;
        // A remplir
        return PAGE_EXISTS;
    }

    /**
     * @param color The aColor to set.
     */
    public void setAColor(Color color) {
        aColor = color;
    }

    /**
     * @param fonte The aFonte to set.
     */
    public void setAFonte(Font fonte) {
        aFonte = fonte;
    }

    /**
     * @param texte The aTexte to set.
     */
    public void setATexte(String texte) {
        aTexte = texte;
    }

    public void setEcartGrille(double valeur) {
        m_GridSize = valeur;
        this.repaint();
    }

    public void setExpPDF(boolean valeur) {
        m_ExpPDF = valeur;
    }

    public void setGridSize(double valeur) {
        if (valeur > MinimumGridSize)
            m_GridSize = valeur;
    };

    public void setGrisLineWidth(int largeur) {
        if (largeur > 0)
            m_GridLineWidth = largeur;
    }

    public void setMarginColor(Color piou) {
        m_MarginColor = piou;
    }

    public void setMarginLineWidth(int largeur) {
        if (largeur > 0)
            m_MarginLineWidth = largeur;
    }

    public void setNonPrintingAreaColor(Color piou) {
        m_NonPrintingAreaColor = piou;
    }
    
    public void setSelectedObject(GraphicObject valeur) {
                m_selectedObject = valeur;
                this.repaint();
    }
    
    public void setShowGrid(boolean valeur) {
        m_ShowGrid = valeur;
    }
    
    public void setSouris(String valeur) {
        m_Souris = valeur;
    }
    
    public void setSurfaceBounds(Rectangle rect) {
        m_SurfaceBounds = rect;
        this.repaint();
    }
    
    public void setSurfaceMargins(Rectangle rect) {
        m_SurfaceMargins = rect;
        this.repaint();
    }
    
    public void setZoom(double coef) {
        if (coef > 0.05) {
            m_Zoom = coef;
        } else {
            m_Zoom = 0.05;
        }
    }
    
    private int typeSouris(String souris) {
        if (souris.equals("RectangleFin")) //$NON-NLS-1$
            return 0;
        if (souris.equals("EllipseFin")) //$NON-NLS-1$
            return 1;
        if (souris.equals("LigneFin")) //$NON-NLS-1$
            return 2;
        if (souris.equals("iiFin")) //$NON-NLS-1$
            return 3;
        if (souris.equals("ilFin")) //$NON-NLS-1$
            return 4;
        if (souris.equals("CarteFin")) //$NON-NLS-1$
            return 5;
        if (souris.equals("LegendeFin")) //$NON-NLS-1$
            return 6;
        if (souris.equals("Echelle")) //$NON-NLS-1$
            return 7;
        return 99;
    }
    
    protected Rectangle zoomRectangle(Rectangle rect) {
        Rectangle newRect;
        newRect = new Rectangle((int) (rect.x * this.m_Zoom), (int) (rect.y * this.m_Zoom), (int) (rect.width * this.m_Zoom), (int) (rect.height * this.m_Zoom));
        return newRect;
    }

	public double getAEchelle() {
		return aEchelle;
	}

	public void setAEchelle(double echelle) {
		aEchelle = echelle;
	}
    
}
