/*
 * 8 avril 2007
 * 
 * SCALP - Système de Cartographie Automatique Libre pour la Pédagogie
 * Version beta 0.94
 *
 * Copyright 1997-2007 Université de Toulouse Le Mirail / Département de Géographie / Laurent Jégou
 * Portions : 	Copyright (c) 2004 Sun Microsystems (file filter, AbstractLayout)
 * 				Copyright 1999, 2000, 2001, 2002 by Bruno Lowagie (iText pdf exports)
 * 				Copyright (C) 2001 Andrew Khan (jxl import/export format Excelé)
 * http://www.univ-tlse2.fr/geoprdc
 * jegou@univ-tlse2.fr
 * 
 * Ce programme est un logiciel libre régi par la licence CeCILL (cf. lien ci-dessous), cette licence confére
 * aux utilisateurs la liberté de modification et de redistribution du logiciel, dans le cadre d'un modéle de
 * diffusion open-source.
 * L'exercice de ces libertés est assorti de certains devoirs é la charge des utilisateurs afin de préserver
 * ce statut au cours des redistributions ultérieures.
 * Léaccessibilité au code source et les droits de copie, de modification et de redistribution qui en découlent
 * ont pour contrepartie de néoffrir aux utilisateurs quéune garantie limitée et de ne faire peser sur léauteur
 * le titulaire des droits patrimoniaux et les concédants successifs quéune responsabilité restreinte.
 * 
 * Le texte intégral de la licence se trouve dans la disribution, ou é l'adresse suivante :
 * http://www.cecill.info
 */

package guiInterface;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStream;
import java.util.Enumeration;
import java.util.Vector;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;
import java.util.zip.ZipOutputStream;

import carto.Carte;
import carto.FondCarte;
import donnees.champDonnees;

/**
 * @author Laurent
 *  
 */
public class FichierSCAP {

    private String baseDir = System.getProperty("user.dir"); //$NON-NLS-1$

    private File m_fichierTemp;

    private File m_fichierFond;

    private File m_fichierDonnees;

    private File m_fichierCarte;

    public File getfichierCarte() {
        return m_fichierCarte;
    }

    public void setfichierCarte(File carte) {
        m_fichierCarte = carte;
    }

    public File getfichierDonnees() {
        return m_fichierDonnees;
    }

    public void setfichierDonnees(File donnees) {
        m_fichierDonnees = donnees;
    }

    public File getfichierFond() {
        return m_fichierFond;
    }

    public void setfichierFond(File fond) {
        m_fichierFond = fond;
    }

    public File getfichierTemp() {
        return m_fichierTemp;
    }

    public void setnomFichier(File fichier) {
        m_fichierTemp = fichier;
    }

    public FichierSCAP() {
        //Constructeur vide pour l'importation MIF/MID;
    }

    public FichierSCAP(String fichierSource) {
        ouvrirZIP(fichierSource);
    }

    public void ouvrirZIP(String fichierSource) {
        final int BUFFER = 2048;

        //Ouverture
        //Copie du fichier dans le rep user
        File inputFile = new File(fichierSource);
        String nomTemp = inputFile.getName().substring(0, inputFile.getName().length() - 5) + ".temp"; //$NON-NLS-1$
        File outputFile = new File(baseDir + System.getProperty("file.separator") + nomTemp); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
        try {
            //Copie temp dans le répertoire user.
            FileInputStream fileIn = new FileInputStream(inputFile);
            BufferedInputStream in = new BufferedInputStream(fileIn);
            FileOutputStream fileOut = new FileOutputStream(outputFile);
            BufferedOutputStream out = new BufferedOutputStream(fileOut, BUFFER);
            int c;
            byte[] reserve = new byte[2048];

            while ((c = in.read(reserve, 0, BUFFER)) != -1)
            	out.write(reserve, 0, c);
            in.close();
            out.close();
            this.m_fichierTemp = outputFile;

            //Décompression
            File sourceZipFile = this.m_fichierTemp;
            File unzipDestinationDirectory = new File(baseDir);
                        
            BufferedOutputStream dest = null;
            ZipFile zipFile = new ZipFile(sourceZipFile);

            Enumeration entries;
            entries = zipFile.entries();

            
            ZipEntry entry;
            while (entries.hasMoreElements()) {
                entry = (ZipEntry) entries.nextElement();
                String currentEntry = entry.getName();
                
                File destFile = new File(unzipDestinationDirectory, currentEntry);
                if (currentEntry.endsWith("f")) //$NON-NLS-1$
                    m_fichierFond = destFile;
                if (currentEntry.endsWith("d")) //$NON-NLS-1$
                    m_fichierDonnees = destFile;
                if (currentEntry.endsWith("c")) //$NON-NLS-1$
                    m_fichierCarte = destFile;

                int currentByte;

                FileOutputStream fos = new FileOutputStream(destFile);
                dest = new BufferedOutputStream(fos, BUFFER);

                byte data[] = new byte[BUFFER];
                InputStream zis = zipFile.getInputStream(entry);

                while ((currentByte = zis.read(data, 0, BUFFER)) != -1) {
                    dest.write(data, 0, currentByte);
                }
                zis.close();
                dest.flush();
                dest.close();
            }
            zipFile.close();
        } catch (IOException ioe) {
            ioe.printStackTrace();
        }
    }

    public void enregistrerZIP(String nomFichier, FondCarte fond, Vector champs, Vector data, Carte carte) {
        int i = 0;
        int j = 0;
        int r = 0;
        final int BUFFER = 2048;
        Vector filesToZip = new Vector(2);

        //Enregistrement fond
        if (fond != null) {
            m_fichierFond = new File(nomFichier + ".f"); //$NON-NLS-1$
            fond.enregistrerFond(m_fichierFond.getPath());
            filesToZip.add(m_fichierFond);
        }
        //Enregistrement données
        if (data != null) {
            m_fichierDonnees = new File(nomFichier + ".d"); //$NON-NLS-1$

            try {
                FileWriter fw = new FileWriter(m_fichierDonnees.getPath());
                BufferedWriter bw = new BufferedWriter(fw);
                String ligne = ""; //$NON-NLS-1$

                bw.write("//Fichier de données SCAPJ"); //$NON-NLS-1$
                bw.newLine();
                bw.write("é" + champs.size() + " Champs"); //$NON-NLS-1$ //$NON-NLS-2$
                bw.newLine();
                for (j = 0; j < champs.size(); j++) {
                    ligne = ((champDonnees) champs.get(j)).nom;
                    ligne = ligne + ";"; //$NON-NLS-1$
                    ligne = ligne + ((champDonnees) champs.get(j)).typeI;
                    bw.write(ligne);
                    bw.newLine();
                }

                bw.write("é" + data.size() + " Donnees"); //$NON-NLS-1$ //$NON-NLS-2$
                bw.newLine();
                for (i = 0; i < data.size(); i++) {
                    if (data.elementAt(i) != null) {
                        ligne = data.elementAt(i).toString();
                        if (ligne.equals("\"\"") || ligne.length() == 0) ligne = "null";
                        ligne = ligne + ";"; //$NON-NLS-1$
                        bw.write(ligne);
                    } else
                        bw.write("null;"); //$NON-NLS-1$
                    if ((i + 1) % j == 0) {
                        bw.newLine();
                    }
                }
                bw.close();
                fw.close();
            } catch (IOException ioe) {
                ioe.printStackTrace();
            }
            filesToZip.add(m_fichierDonnees);
        }
        //Enregistrement carte
        if (carte != null) {
            m_fichierCarte = new File(nomFichier + ".c"); //$NON-NLS-1$
            carte.enregistrerCarte(m_fichierCarte.getPath());
            filesToZip.add(m_fichierCarte);
        }

        byte[] tampon = new byte[BUFFER];
        String zipFileName = nomFichier;
        //Compression
        try {
            BufferedInputStream origine = null;
            FileOutputStream dest = new FileOutputStream(zipFileName);
            ZipOutputStream out = new ZipOutputStream(new BufferedOutputStream(dest));
            for (i = 0; i < filesToZip.size(); i++) {
                FileInputStream in = new FileInputStream((File) filesToZip.elementAt(i));
                origine = new BufferedInputStream(in, BUFFER);
                out.putNextEntry(new ZipEntry(((File) filesToZip.elementAt(i)).getName()));
                int len;
                while ((len = origine.read(tampon, 0, BUFFER)) != -1) {
                    out.write(tampon, 0, len);
                }
                origine.close();
            }
            out.close();
        } catch (IllegalArgumentException iae) {
            iae.printStackTrace();
        } catch (FileNotFoundException fnfe) {
            fnfe.printStackTrace();
        } catch (IOException ioe) {
            ioe.printStackTrace();
        }
        for (i = 0; i < filesToZip.size(); i++) {
            ((File) filesToZip.elementAt(i)).delete();
        }
    }
}