/*
 * 8 avril 2007
 * 
 * SCALP - Système de Cartographie Automatique Libre pour la Pédagogie
 * Version beta 0.94
 *
 * Copyright 1997-2007 Université de Toulouse Le Mirail / Département de Géographie / Laurent Jégou
 * Portions : 	Copyright (c) 2004 Sun Microsystems (file filter, AbstractLayout)
 * 				Copyright 1999, 2000, 2001, 2002 by Bruno Lowagie (iText pdf exports)
 * 				Copyright (C) 2001 Andrew Khan (jxl import/export format Excelé)
 * http://www.univ-tlse2.fr/geoprdc
 * jegou@univ-tlse2.fr
 * 
 * Ce programme est un logiciel libre régi par la licence CeCILL (cf. lien ci-dessous), cette licence confére
 * aux utilisateurs la liberté de modification et de redistribution du logiciel, dans le cadre d'un modéle de
 * diffusion open-source.
 * L'exercice de ces libertés est assorti de certains devoirs é la charge des utilisateurs afin de préserver
 * ce statut au cours des redistributions ultérieures.
 * Léaccessibilité au code source et les droits de copie, de modification et de redistribution qui en découlent
 * ont pour contrepartie de néoffrir aux utilisateurs quéune garantie limitée et de ne faire peser sur léauteur
 * le titulaire des droits patrimoniaux et les concédants successifs quéune responsabilité restreinte.
 * 
 * Le texte intégral de la licence se trouve dans la disribution, ou é l'adresse suivante :
 * http://www.cecill.info
 */

package guiInterface;

import java.awt.Color;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Point;

import javax.swing.JComponent;
import javax.swing.JInternalFrame;

import carto.Carte;
import carto.ClasseDiscret;
import carto.FondCarte;
import carto.MetaPolygone;
import carto.ParamsPolygone;

/**
 * @author Laurent
 *  
 */

public class PanneauLegende extends JComponent {

	private JInternalFrame base;
	
	private Carte carte;

	private FondCarte fond;

	private int hauteurMini;

	public PanneauLegende(Carte carte, FondCarte fond, FenetreLegende FL) {
		super();
		this.base = FL;
		this.fond = fond;
		this.carte = carte;
	}

	public Carte getCarte() {
		return carte;
	}

	public void setCarte(Carte carte) {
		this.carte = carte;
	}

	public FondCarte getFond() {
		return fond;
	}

	public void setFond(FondCarte fond) {
		this.fond = fond;
	}

	public void paint(Graphics g) {
		Graphics2D g2 = (Graphics2D) g;
		int i = 0;
		int hauteurMini = 0;

		switch (carte.getTypeAnalyse()) {
		case 1: //Choropléthes
			genereLegendeCh(g2);
			break;
		case 2: //Symboliques
			genereLegendeSy(g);
			break;
		case 3: //Plages sous les symboles
			genereLegendeCh(g2);
			genereLegendeSy(g);
			break;
		case 4: //Plages dans les symboles
			genereLegendeCh(g2);
			genereLegendeSy(g);
			break;
		}
	}

	private void genereLegendeCh(Graphics2D g2) {
		int i;
		int nbCl = carte.analysePlages.nbreClasses;
		g2.setFont(carte.getPoliceLegende());
		hauteurMini = 30 + (nbCl * 20);
		for (i = 0; i < nbCl; i++) {
			g2.setPaint(((ClasseDiscret) carte.analysePlages.classes.elementAt(i)).couleur);
			g2.fillRect(10, hauteurMini - ((i * 20) + 6), 30, 14);
			g2.setPaint(Color.black);
			g2.drawRect(10, hauteurMini - ((i * 20) + 6), 30, 14);
			g2.drawString(((ClasseDiscret) carte.analysePlages.classes.elementAt(i)).titreLeg, 44, hauteurMini - ((i * 20) - 6));
		}
	}

	private void genereLegendeSy(Graphics g) {
		int my = 0;
		int diametre = 0;
		int diamMax = 0;
		double coefAf = 1;
		ParamsPolygone pr;
		int h;
		double coefMEP = 1;
		if (fond.isPourMEP()) {
			coefAf= fond.getCoefMEP();
		} else {
			coefAf = carte.analyseSymb.cS;
		}
		pr = (ParamsPolygone) ((MetaPolygone) fond.getEnsMetaPoly().elementAt(carte.analyseSymb.legMaxIndex)).getParams();
		diamMax = (int) (pr.tailleSymbole * coefAf);
		if (carte.getTypeAnalyse() > 2) {
			h = diamMax + 40 + (carte.analysePlages.nbreClasses + 2) * 20;
			this.base.setSize(240, 30 + h);
		} else {
			h = 120 + diamMax;
		}
		Point centre = new Point(80, h);
		if (carte.analyseSymb.legMinIndex != fond.getEnsMetaPoly().size() + 1) {
			pr = (ParamsPolygone) ((MetaPolygone) fond.getEnsMetaPoly().elementAt(carte.analyseSymb.legMinIndex)).getParams();
			diametre = (int) (pr.tailleSymbole * coefAf);
			my = centre.y - diametre;
		}
		switch(carte.analyseSymb.typeSymbole) {
		case 0: 
			if (carte.analyseSymb.legMinIndex != fond.getEnsMetaPoly().size() + 1) {
				g.drawOval(centre.x - (diametre / 2), my, diametre, diametre);
				g.drawLine(centre.x, my, centre.x + (diamMax / 2) + 20, my);
				g.drawString(String.valueOf(carte.analyseSymb.legMinValeur), centre.x + (diamMax / 2) + 12, my);
			}
			if (carte.analyseSymb.legMedIndex != fond.getEnsMetaPoly().size() + 1) {
				pr = (ParamsPolygone) ((MetaPolygone) fond.getEnsMetaPoly().elementAt(carte.analyseSymb.legMedIndex)).getParams();
				diametre = (int) (pr.tailleSymbole * coefAf);
				my = centre.y - diametre;
				g.drawOval(centre.x - (diametre / 2), my, diametre, diametre);
				g.drawLine(centre.x, my, centre.x + (diamMax / 2) + 20, my);
				g.drawString(String.valueOf(carte.analyseSymb.legMedValeur), centre.x + (diamMax / 2) + 12, my);
			}
			pr = (ParamsPolygone) ((MetaPolygone) fond.getEnsMetaPoly().elementAt(carte.analyseSymb.legMaxIndex)).getParams();
			my = centre.y - diamMax;
			g.drawOval(centre.x - (diamMax / 2), my, diamMax, diamMax);
			g.drawLine(centre.x, my, centre.x + (diamMax / 2) + 20, my);
			g.drawString(String.valueOf(carte.analyseSymb.legMaxValeur), centre.x + (diamMax / 2) + 12, my);
			break;
		case 1:
			if (carte.analyseSymb.legMinIndex != fond.getEnsMetaPoly().size() + 1) {         	
				g.drawRect(centre.x - (diametre / 2), my, diametre, diametre);
				g.drawLine(centre.x, my, centre.x + (diamMax / 2) + 20, my);
				g.drawString(String.valueOf(carte.analyseSymb.legMinValeur), centre.x + (diamMax / 2) + 12, my);
			}	
			if (carte.analyseSymb.legMedIndex != fond.getEnsMetaPoly().size() + 1) {
				pr = (ParamsPolygone) ((MetaPolygone) fond.getEnsMetaPoly().elementAt(carte.analyseSymb.legMedIndex)).getParams();
				diametre = (int) (pr.tailleSymbole * coefAf);
				my = centre.y - diametre;
				g.drawRect(centre.x - (diametre / 2), my, diametre, diametre);
				g.drawLine(centre.x, my, centre.x + (diamMax / 2) + 20, my);
				g.drawString(String.valueOf(carte.analyseSymb.legMedValeur), centre.x + (diamMax / 2) + 12, my);
			}
			pr = (ParamsPolygone) ((MetaPolygone) fond.getEnsMetaPoly().elementAt(carte.analyseSymb.legMaxIndex)).getParams();
			my = centre.y - diamMax;
			g.drawRect(centre.x - (diamMax / 2), my, diamMax, diamMax);
			g.drawLine(centre.x, my, centre.x + (diamMax / 2) + 20, my);
			g.drawString(String.valueOf(carte.analyseSymb.legMaxValeur), centre.x + (diamMax / 2) + 12, my);
			break;	            	
		}
	}
}